@@ -18,21 +18,25 @@ class SimpleOptionsHandler(BaseOptionsHandler):
         annotation = func.__annotations__
         al = []
         for a in args:
-            arg = options.get(False)
+            try:
+                arg = options.get(False)
+            except Empty:
+                break
+
             arg_type = annotation.get(a)
 
             if arg_type == int:
                 if arg.isdigit():
                     arg = int(arg)
                 else:
-                    error = f'参数<{a}> 得到值"{arg}" 无法解析为int'
+                    error = f'"{arg}" is not a int'
                     raise TypeError(error)
 
             if arg_type == float:
                 try:
                     arg = float(arg)
                 except ValueError:
-                    error = f'参数<{a}> 得到值"{arg}" 无法解析为float'
+                    error = f'"{arg}" is not a float'
                     raise TypeError(error)
 
             al.append(arg)
@@ -79,5 +83,6 @@ class SimpleOptionsHandler(BaseOptionsHandler):
                         if arg in func.__kwdefaults__:
                             break
                     else:
-                        raise NotImplementedError(f'缺少参数"{arg}"')
+                        msg = f'Miss parameter "{arg}"'
+                        raise ValueError(msg)
         return res
